/**
 * Copyright Copyright 2008-14 Simon Andrews
 *
 *    This file is part of FocalPoint.
 *
 *    FocalPoint is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FocalPoint is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with StackMeasure; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.FocalPoint.GUI.Thumbnail;

import ij.IJ;
import ij.ImagePlus;
import java.io.File;
import java.io.IOException;


public class SimpleThumbnailPanel extends ThumbnailPanel {
	
	private static final String [] validExtensions = new String [] {
		"tiff",
		"tif",
		"png",
		"jpeg",
		"jpg",
		"bmp",
		"fts",
		"fits",
	};
	
	public SimpleThumbnailPanel (FileDetailsPanel fileDetails) throws IncompatibleFileTypeException {
		super(fileDetails);
	}

	public ImagePlus [] loadImages (File file) throws IOException {
		return new ImagePlus [] {IJ.openImage(file.getAbsolutePath())};
	}

	boolean isImage() {
		return true;
	}

	long getFileSize(File file) {
		return file.length();
	}

	boolean shouldDeferLoading(File file) {
		if (file.length()>(50*1024*1024)) {
			return true;
		}
		return false;
	}

	boolean canReadFile(File file) {
		String name = fileDetails.file().getName().toLowerCase();

		for (int i=0;i<validExtensions.length;i++) {
			if (name.endsWith(validExtensions[i])) {
				return true;
			}
		}
		return false;
	}
		
}
